# Record architecture decisions

* Status: proposed
* Date: 2020-03-25

## Context

We need to record the architectural decisions made on Opinionated Digital Center.

## Decision

We will use Architecture Decision Records, as [described by Michael Nygard](http://thinkrelevance.com/blog/2011/11/15/documenting-architecture-decisions).

## Consequences

See Michael Nygard's article, linked above.
